from pattern.graph import Graph

g = Graph()
for n1, n2 in (
	('cat', 'tail'), ('cat', 'purr'), ('purr', 'sound'),
	('dog', 'tail'), ('dog', 'bark'), ('bark', 'sound')):
	g.add_node(n1)
	g.add_node(n2)
	g.add_edge(n1, n2, weight=0.0, type='is-related-to')

	g.export(
		'graph-sound', 
		width=1000,
		height=800,
		directed=True,
		weighted=True,
		pack=True
		)

# Graph.export() creates a new file folder at the given path with an index.html (the visualization), a style.css, graphs.js and canvas.js. The optional parameter javascript defines the URL path to graph.js and canvas.js (which will not be included in this case).
# http://www.clips.ua.ac.be/pages/pattern-graph#Visualization
# http://networkx.github.io/ is used

# The following parameters can be used to customize the visualization:
# **********************************************************************
# Parameter 	Default 			Description
# javascript 	'' 					Path to canvas.js and graph.js.
# stylesheet 	INLINE 				Path to CSS: INLINE, DEFAULT (generates style.css), None or path.
# title 		'Graph' 			HTML <title>Graph</title>.
# id 			'graph' 			HTML <div id="graph"> contains the <canvas>.
 
# ctx 			'canvas.element' 	HTML <canvas> element to use for drawing.
# width 		700 				Canvas width in pixels.
# height 		500 				Canvas height in pixels.
# frames 		500 				Number of frames of animation.
# ipf 			2 					GraphLayout.update() iterations per frame.
 
# directed 		False 				Visualize eigenvector centrality as an edge arrow?
# weighted 		False 				Visualize betweenness centrality as a node shadow?
# pack 			True 				Shorten leaf edges + add node weight to node radius.
 
# distance 		graph.distance 		Average edge length.
# k 			graph.k 			Force constant.
# force 		graph.force 		Force dampener.
# repulsion 	graph.repulsion 	Force radius.
 
# href 			{} 					Dictionary of Node.id => URL.
# css 			{} 					Dictionary of Node.id => CSS classname.

# **********************************************************************
# To export a static visualization, use frames=1 and ipf=0.
